@@ -14,11 +14,14 @@ SUPPORT_TARGET_TEMPERATURE = 1
 SUPPORT_PRESET_MODE = 16
 
 # Supported cover features
+SUPPORT_OPEN = 1
+SUPPORT_CLOSE = 2
 SUPPORT_SET_POSITION = 4
 
 # HVAC modes
 HVAC_MODE_OFF = "off"
 HVAC_MODE_HEAT = "heat"
+HVAC_MODE_AUTO = "auto"
 
 # HVAC states
 CURRENT_HVAC_OFF = "off"
